==> ifrit_3.2.5.orig.tar.gz: ifrit-3.2.5/core/iactor.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


//
//  A combined class for ALL IFrIT actors & mappers - they must be the same so that renderers
//  can be copied. Thus, it is the most general scaled LOD actor.
//  This actor will render itself efficiently in multiple windows.
//
//
#ifndef IACTOR_H
#define IACTOR_H


#include <vtkLODActor.h>


#include "iarray.h"

class iActor;
class iDataLimits;
class iLookupTable;
class iPalette;

class vtkPlane;
class vtkPolyData;
class vtkPolyDataMapper;


class iActorSubject
{
	//
	//  It is really just a struct...
	//
	friend class iActor;
	friend class iActorSubjectPointer;

private:

	iActorSubject(iActor *parent, vtkWindow *win);
	virtual ~iActorSubject();

	vtkWindow *mWindow;
	vtkPolyDataMapper *mMapper;
	vtkMapperCollection *mLODMappers;
};


class iActorSubjectPointer
{

public:

	iActorSubjectPointer(iActorSubject *subject);
	iActorSubjectPointer(){ mPointer = 0; }

	inline iActorSubject* Pointer() const { return mPointer; }
	inline iActorSubject* operator->() const { return mPointer; }

	void operator=(iActorSubject *p);
	void operator=(const iActorSubjectPointer &p);
	bool operator==(const iActorSubjectPointer &p) const;
	bool operator<(const iActorSubjectPointer &p) const;

private:

	iActorSubject *mPointer;
};


class iActor: public vtkLODActor 
{
	
public:
	
	vtkTypeMacro(iActor,vtkLODActor);
	static iActor* New(bool scaled = false);

	virtual void ReleaseGraphicsResources(vtkWindow *win);
	virtual void Render(vtkRenderer *ren, vtkMapper *m);

	inline bool GetScaled(){ return mScaled; }
	void SetScaled(bool s);

	inline double GetBasicScale(){ return mBasicScale; }
	void SetBasicScale(double s);

	inline const double* GetAxisScale(){ return mAxisScale; }
	void SetAxisScale(double sx, double sy, double sz);

	//
	//  Mapper functionality
	//
	void SetInput(vtkPolyData *data);
	void SetScalarVisibility(bool s);
	void SetScalarRange(float min, float max);

	void SyncWithLimits(iDataLimits *l, int v, float scale = 1.0f);
	inline iLookupTable* GetLookupTable() const { return mLookupTable; }

	void AddMapperObserver(unsigned long event, vtkCommand *obs);

	void AddClippingPlane(vtkPlane *plane);
	void RemoveClippingPlane(vtkPlane *plane);

	void ColorByArrayComponent(int arrayNum, int component);

protected:
	
	iActor(bool scaled);
	virtual ~iActor();
	
private:

	bool SetCurrentWindow(vtkWindow *win);

	double mBasicScale, mAxisScale[3];
	bool mScaled;
	iOrderedArray<iActorSubjectPointer> mSubjects;
	iActorSubject *mDummySubject, *mCurrentSubject;
	iActorSubjectPointer mDummySubjectPointer;
	vtkPolyDataMapper *mDefaultMapper;
	vtkMapperCollection *mDefaultLODMappers; 
	iLookupTable *mLookupTable;
};

#endif // IACTOR_H

==> ifrit_3.2.8.orig.tar.gz: ifrit-3.2.8/core/iactor.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


//
//  A combined class for ALL IFrIT actors & mappers - they must be the same so that renderers
//  can be copied. Thus, it is the most general scaled LOD actor.
//  This actor will render itself efficiently in multiple windows.
//
//
#ifndef IACTOR_H
#define IACTOR_H


#include <vtkLODActor.h>


#include "iarray.h"

class iActor;
class iArtifactCorrector;
class iDataLimits;
class iLookupTable;
class iPalette;

class vtkPlane;
class vtkPolyData;
class vtkPolyDataMapper;


class iActorSubject
{
	//
	//  It is really just a struct...
	//
	friend class iActor;
	friend class iActorSubjectPointer;

private:

	iActorSubject(iActor *parent, vtkWindow *win);
	virtual ~iActorSubject();

	vtkWindow *mWindow;
	vtkPolyDataMapper *mMapper;
	vtkMapperCollection *mLODMappers;
};


class iActorSubjectPointer
{

public:

	iActorSubjectPointer(iActorSubject *subject);
	iActorSubjectPointer(){ mPointer = 0; }

	inline iActorSubject* Pointer() const { return mPointer; }
	inline iActorSubject* operator->() const { return mPointer; }

	void operator=(iActorSubject *p);
	void operator=(const iActorSubjectPointer &p);
	bool operator==(const iActorSubjectPointer &p) const;
	bool operator<(const iActorSubjectPointer &p) const;

private:

	iActorSubject *mPointer;
};


class iActor: public vtkLODActor 
{
	
public:
	
	vtkTypeMacro(iActor,vtkLODActor);
	static iActor* New(bool scaled = false);

	virtual void ReleaseGraphicsResources(vtkWindow *win);
	virtual void Render(vtkRenderer *ren, vtkMapper *m);

	inline bool GetScaled(){ return mScaled; }
	void SetScaled(bool s);

	inline double GetBasicScale(){ return mBasicScale; }
	void SetBasicScale(double s);

	inline const double* GetAxisScale(){ return mAxisScale; }
	void SetAxisScale(double sx, double sy, double sz);

	//
	//  Mapper functionality
	//
	void SetInput(vtkPolyData *data);
	void SetScalarVisibility(bool s);
	void SetScalarRange(float min, float max);

	void SyncWithLimits(iDataLimits *l, int v, float scale = 1.0f);
	inline iLookupTable* GetLookupTable() const { return mLookupTable; }

	void AddMapperObserver(unsigned long event, vtkCommand *obs);

	void AddClippingPlane(vtkPlane *plane);
	void RemoveClippingPlane(vtkPlane *plane);

	void ColorByArrayComponent(int arrayNum, int component);

	void InstallArtifactCorrector(iArtifactCorrector *c);

protected:
	
	iActor(bool scaled = false);
	virtual ~iActor();
	
private:

	bool SetCurrentWindow(vtkWindow *win);

	double mBasicScale, mAxisScale[3];
	bool mScaled;
	iOrderedArray<iActorSubjectPointer> mSubjects;
	iActorSubject *mDummySubject, *mCurrentSubject;
	iActorSubjectPointer mDummySubjectPointer;
	vtkPolyDataMapper *mDefaultMapper;
	vtkMapperCollection *mDefaultLODMappers; 
	iLookupTable *mLookupTable;
	iArtifactCorrector *mCorrector;
};

#endif // IACTOR_H
